==> parcel-bundler-vue-1.6.3.tgz: package/lib/Logger.js <==
'use strict';

var _getOwnPropertyNames = require('babel-runtime/core-js/object/get-own-property-names');

var _getOwnPropertyNames2 = _interopRequireDefault(_getOwnPropertyNames);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var chalk = require('chalk');
var readline = require('readline');
var prettyError = require('./utils/prettyError');
var emoji = require('./utils/emoji');

var _require = require('grapheme-breaker'),
    countBreaks = _require.countBreaks;

var stripAnsi = require('strip-ansi');

var Logger = function () {
  function Logger(options) {
    (0, _classCallCheck3.default)(this, Logger);

    this.lines = 0;
    this.statusLine = null;
    this.setOptions(options);
  }

  (0, _createClass3.default)(Logger, [{
    key: 'setOptions',
    value: function setOptions(options) {
      this.logLevel = options && typeof options.logLevel === 'number' ? options.logLevel : 3;
      this.color = options && typeof options.color === 'boolean' ? options.color : chalk.supportsColor;
      this.chalk = new chalk.constructor({ enabled: this.color });
    }
  }, {
    key: 'write',
    value: function write(message) {
      var persistent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

      if (!persistent) {
        this.lines += message.split('\n').length;
      }

      this._log(message);
    }
  }, {
    key: 'log',
    value: function log(message) {
      if (this.logLevel < 3) {
        return;
      }

      this.write(message);
    }
  }, {
    key: 'persistent',
    value: function persistent(message) {
      if (this.logLevel < 3) {
        return;
      }

      this.write(this.chalk.bold(message), true);
    }
  }, {
    key: 'warn',
    value: function warn(err) {
      if (this.logLevel < 2) {
        return;
      }

      var _prettyError = prettyError(err, { color: this.color }),
          message = _prettyError.message,
          stack = _prettyError.stack;

      this.write(this.chalk.yellow(emoji.warning + '  ' + message));
      if (stack) {
        this.write(stack);
      }
    }
  }, {
    key: 'error',
    value: function error(err) {
      if (this.logLevel < 1) {
        return;
      }

      var _prettyError2 = prettyError(err, { color: this.color }),
          message = _prettyError2.message,
          stack = _prettyError2.stack;

      this.status(emoji.error, message, 'red');
      if (stack) {
        this.write(stack);
      }
    }
  }, {
    key: 'clear',
    value: function clear() {
      if (!this.color) {
        return;
      }

      while (this.lines > 0) {
        readline.clearLine(process.stdout, 0);
        readline.moveCursor(process.stdout, 0, -1);
        this.lines--;
      }

      readline.cursorTo(process.stdout, 0);
      this.statusLine = null;
    }
  }, {
    key: 'writeLine',
    value: function writeLine(line, msg) {
      if (!this.color) {
        return this.log(msg);
      }

      var n = this.lines - line;
      var stdout = process.stdout;
      readline.cursorTo(stdout, 0);
      readline.moveCursor(stdout, 0, -n);
      stdout.write(msg);
      readline.clearLine(stdout, 1);
      readline.cursorTo(stdout, 0);
      readline.moveCursor(stdout, 0, n);
    }
  }, {
    key: 'status',
    value: function status(emoji, message) {
      var color = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'gray';

      if (this.logLevel < 3) {
        return;
      }

      var hasStatusLine = this.statusLine != null;
      if (!hasStatusLine) {
        this.statusLine = this.lines;
      }

      this.writeLine(this.statusLine, this.chalk[color].bold(emoji + '  ' + message));

      if (!hasStatusLine) {
        process.stdout.write('\n');
        this.lines++;
      }
    }
  }, {
    key: 'handleMessage',
    value: function handleMessage(options) {
      this[options.method].apply(this, (0, _toConsumableArray3.default)(options.args));
    }
  }, {
    key: '_log',
    value: function _log(message) {
      console.log(message);
    }
  }, {
    key: 'table',
    value: function table(columns, _table) {
      // Measure column widths
      var colWidths = [];
      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = (0, _getIterator3.default)(_table), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var row = _step.value;

          var i = 0;
          var _iteratorNormalCompletion3 = true;
          var _didIteratorError3 = false;
          var _iteratorError3 = undefined;

          try {
            for (var _iterator3 = (0, _getIterator3.default)(row), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
              var item = _step3.value;

              colWidths[i] = Math.max(colWidths[i] || 0, stringWidth(item));
              i++;
            }
          } catch (err) {
            _didIteratorError3 = true;
            _iteratorError3 = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion3 && _iterator3.return) {
                _iterator3.return();
              }
            } finally {
              if (_didIteratorError3) {
                throw _iteratorError3;
              }
            }
          }
        }

        // Render rows
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = (0, _getIterator3.default)(_table), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          var _row = _step2.value;

          var items = _row.map(function (item, i) {
            // Add padding between columns unless the alignment is the opposite to the
            // next column and pad to the column width.
            var padding = !columns[i + 1] || columns[i + 1].align === columns[i].align ? 4 : 0;
            return pad(item, colWidths[i] + padding, columns[i].align);
          });

          this.log(items.join(''));
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }
    }
  }]);
  return Logger;
}();

// Pad a string with spaces on either side


function pad(text, length) {
  var align = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'left';

  var pad = ' '.repeat(length - stringWidth(text));
  if (align === 'right') {
    return pad + text;
  }

  return text + pad;
}

// Count visible characters in a string
function stringWidth(string) {
  return countBreaks(stripAnsi('' + string));
}

// If we are in a worker, make a proxy class which will
// send the logger calls to the main process via IPC.
// These are handled in WorkerFarm and directed to handleMessage above.
if (process.send) {
  var LoggerProxy = function LoggerProxy() {
    (0, _classCallCheck3.default)(this, LoggerProxy);
  };

  var _loop = function _loop(method) {
    LoggerProxy.prototype[method] = function () {
      for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      process.send({
        type: 'logger',
        method: method,
        args: args
      });
    };
  };

  var _iteratorNormalCompletion4 = true;
  var _didIteratorError4 = false;
  var _iteratorError4 = undefined;

  try {
    for (var _iterator4 = (0, _getIterator3.default)((0, _getOwnPropertyNames2.default)(Logger.prototype)), _step4; !(_iteratorNormalCompletion4 = (_step4 = _iterator4.next()).done); _iteratorNormalCompletion4 = true) {
      var method = _step4.value;

      _loop(method);
    }
  } catch (err) {
    _didIteratorError4 = true;
    _iteratorError4 = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion4 && _iterator4.return) {
        _iterator4.return();
      }
    } finally {
      if (_didIteratorError4) {
        throw _iteratorError4;
      }
    }
  }

  module.exports = new LoggerProxy();
} else {
  module.exports = new Logger();
}

==> parcel-bundler-vue-2.0.0.tgz: package/lib/Logger.js <==
'use strict';

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var chalk = require('chalk');
var readline = require('readline');
var prettyError = require('./utils/prettyError');
var emoji = require('./utils/emoji');

var Logger = function () {
  function Logger(options) {
    (0, _classCallCheck3.default)(this, Logger);

    this.logLevel = typeof options.logLevel === 'number' ? options.logLevel : 3;
    this.color = typeof options.color === 'boolean' ? options.color : chalk.supportsColor;
    this.chalk = new chalk.constructor({ enabled: this.color });
    this.lines = 0;
    this.statusLine = null;
  }

  (0, _createClass3.default)(Logger, [{
    key: 'write',
    value: function write(message) {
      var persistent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

      if (!persistent) {
        this.lines += message.split('\n').length;
      }

      console.log(message);
    }
  }, {
    key: 'log',
    value: function log(message) {
      if (this.logLevel < 3) {
        return;
      }

      this.write(message);
    }
  }, {
    key: 'persistent',
    value: function persistent(message) {
      if (this.logLevel < 3) {
        return;
      }

      this.write(this.chalk.bold(message), true);
    }
  }, {
    key: 'warn',
    value: function warn(message) {
      if (this.logLevel < 2) {
        return;
      }

      this.write(this.chalk.yellow(emoji.warning + ' ' + message));
    }
  }, {
    key: 'error',
    value: function error(err) {
      if (this.logLevel < 1) {
        return;
      }

      var _prettyError = prettyError(err, { color: this.color }),
          message = _prettyError.message,
          stack = _prettyError.stack;

      this.status(emoji.error, message, 'red');
      if (stack) {
        this.write(stack);
      }
    }
  }, {
    key: 'clear',
    value: function clear() {
      if (!this.color) {
        return;
      }

      while (this.lines > 0) {
        readline.clearLine(process.stdout, 0);
        readline.moveCursor(process.stdout, 0, -1);
        this.lines--;
      }

      readline.cursorTo(process.stdout, 0);
      this.statusLine = null;
    }
  }, {
    key: 'writeLine',
    value: function writeLine(line, msg) {
      if (!this.color) {
        return this.log(msg);
      }

      var n = this.lines - line;
      var stdout = process.stdout;
      readline.cursorTo(stdout, 0);
      readline.moveCursor(stdout, 0, -n);
      stdout.write(msg);
      readline.clearLine(stdout, 1);
      readline.cursorTo(stdout, 0);
      readline.moveCursor(stdout, 0, n);
    }
  }, {
    key: 'status',
    value: function status(emoji, message) {
      var color = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'gray';

      if (this.logLevel < 3) {
        return;
      }

      var hasStatusLine = this.statusLine != null;
      if (!hasStatusLine) {
        this.statusLine = this.lines;
      }

      this.writeLine(this.statusLine, this.chalk[color].bold(emoji + '  ' + message));

      if (!hasStatusLine) {
        process.stdout.write('\n');
        this.lines++;
      }
    }
  }]);
  return Logger;
}();

module.exports = Logger;
